
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: BINDING_HEADER_SIXUI, BINDING_NAME_SIXUI_NOTHING_1, BINDING_NAME_SIXUI_NOTHING_2, BINDING_NAME_SIXUI_NOTHING_3, BINDING_NAME_SIXUI_NOTHING_4, BINDING_NAME_SIXUI_NOTHING_5, BINDING_NAME_SIXUI_TELLTARGET, BNGetInfo, BNSetCustomMessage, GetMinimapShape, ReloadUI, select, SixUI_GetLayout, SixUI_IsClutterKeyDown

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database

-------------------------------------------------------------------------------
-- Bindings
-------------------------------------------------------------------------------

BINDING_HEADER_SIXUI = "SixUI"
BINDING_NAME_SIXUI_TELLTARGET = "Tell Target"
BINDING_NAME_SIXUI_NOTHING_1 = "Nothing 1"
BINDING_NAME_SIXUI_NOTHING_2 = "Nothing 2"
BINDING_NAME_SIXUI_NOTHING_3 = "Nothing 3"
BINDING_NAME_SIXUI_NOTHING_4 = "Nothing 4"
BINDING_NAME_SIXUI_NOTHING_5 = "Nothing 5"

-------------------------------------------------------------------------------
-- Dialogs
-------------------------------------------------------------------------------

StaticPopupDialogs["SIXUI_SETUP"] = {
	preferredIndex = STATICPOPUP_NUMDIALOGS,
	text = "Please reload to finish setting up SixUI.",
	button1 = RELOADUI,
	OnAccept = function ()
		A:GetModule("Core Setup"):Setup()
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = false,
}

StaticPopupDialogs["SIXUI_RESET_ADDON"] = {
	preferredIndex = STATICPOPUP_NUMDIALOGS,
	text = "Warning: Resetting the SixUI profile for '%s' may remove any changes you have made.",
	button1 = CONTINUE,
	button2 = CANCEL,
	OnAccept = function (self, variables)
		local M = A:GetModule("Core Setup")
		M:ResetVariables(variables)
		M:OnEnable()
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = false,
}

StaticPopupDialogs["SIXUI_RESET_ALL"] = {
	preferredIndex = STATICPOPUP_NUMDIALOGS,
	text = "Warning: Resetting the SixUI profile for all AddOns may remove any changes you have made.",
	button1 = CONTINUE,
	button2 = CANCEL,
	OnAccept = function ()
		local M = A:GetModule("Core Setup")
		M:ResetVariables(M.SAVED_VARIABLES)
		M:OnEnable()
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = false,
}

StaticPopupDialogs["SIXUI_RESET_CVARS"] = {
	preferredIndex = STATICPOPUP_NUMDIALOGS,
	text = "Warning: Loading SixUI's recommended CVars may remove any changes you have made to Blizzard's user interface options.",
	button1 = CONTINUE,
	button2 = CANCEL,
	OnAccept = function ()
		A:GetModule("Core Setup"):SetCVars()
		ReloadUI()
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = false,
}

StaticPopupDialogs["SIXUI_SET_BROADCAST"] = {
	preferredIndex = STATICPOPUP_NUMDIALOGS,
	text = BATTLENET_BROADCAST,
	button1 = UPDATE,
	button2 = CANCEL,
	hasEditBox = true,
	maxLetters = 127,
	countInvisibleLetters = true,
	editBoxWidth = 350,
	OnAccept = function (self)
		if self.editBox:GetText() ~= select(4, BNGetInfo()) then
			BNSetCustomMessage(self.editBox:GetText())
		end
	end,
	OnShow = function (self)
		self.editBox:SetText(select(4, BNGetInfo()))
		self.editBox:SetFocus()
	end,
	EditBoxOnEnterPressed = function (self)
		if self:GetText() ~= select(4, BNGetInfo()) then
			BNSetCustomMessage(self:GetText())
		end

		self:GetParent():Hide()
	end,
	EditBoxOnEscapePressed = function (self)
		self:GetParent():Hide()
	end,
	timeout = 0,
	exclusive = true,
	whileDead = true,
	hideOnEscape = true,
}

StaticPopupDialogs["SET_BNFRIENDNOTE"].preferredIndex = STATICPOPUP_NUMDIALOGS

-------------------------------------------------------------------------------
-- Helpers
-------------------------------------------------------------------------------

function GetMinimapShape()
	return "SQUARE"
end

function SixUI_GetLayout()
	return A:GetLayout()
end

function SixUI_IsClutterKeyDown()
	return C.CLUTTER_KEY_FUNCTION()
end
